==> qtjambi-dbus-debuginfo-macos-5.15.20.jar: sources/QtJambiDBus/QDBusPendingCall_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtDBus/qdbuspendingcall.h>
#include <QtCore/QVariant>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDBusPendingCall(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDBusPendingCall")
    QDBusPendingCall *_ptr = reinterpret_cast<QDBusPendingCall *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDBusPendingCall(QDBusPendingCall)
void __qt_construct_QDBusPendingCall_cref_QDBusPendingCall(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusPendingCall(QDBusPendingCall)")
    jobject other0 = __java_arguments[0].l;
    const QDBusPendingCall& __qt_other0 = qtjambi_cast<const QDBusPendingCall& >(__jni_env, other0);
    QDBusPendingCall *__qt_this = new(__qtjambi_ptr) QDBusPendingCall(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDBusPendingCall::QDBusPendingCall(QDBusPendingCall)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_initialize_1native__Lio_qt_dbus_QDBusPendingCall_2Lio_qt_dbus_QDBusPendingCall_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusPendingCall::QDBusPendingCall(QDBusPendingCall)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusPendingCall_cref_QDBusPendingCall, sizeof(QDBusPendingCall), typeid(QDBusPendingCall), false, &deleter_QDBusPendingCall, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDBusPendingCall
void __qt_destruct_QDBusPendingCall(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDBusPendingCall")
    reinterpret_cast<QDBusPendingCall*>(ptr)->~QDBusPendingCall();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDBusPendingCall::error()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_error_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::error()const", __qt_this)
        QDBusError __qt_return_value = __qt_this->QDBusPendingCall::error();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::isError()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_isError_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::isError()const", __qt_this)
        __java_return_value = __qt_this->QDBusPendingCall::isError();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::isFinished()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_isFinished_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::isFinished()const", __qt_this)
        __java_return_value = __qt_this->QDBusPendingCall::isFinished();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::isValid()const", __qt_this)
        __java_return_value = __qt_this->QDBusPendingCall::isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::operator=(QDBusPendingCall)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_assign_1native_1cref_1QDBusPendingCall__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    QTJAMBI_TRY {
        QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::operator=(QDBusPendingCall)", __qt_this)
        const QDBusPendingCall& __qt_other0 = QtJambiAPI::interfaceReferenceFromNativeId<QDBusPendingCall>(__jni_env, other0);
        __qt_this->QDBusPendingCall::operator=(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusPendingCall::reply()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_reply_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::reply()const", __qt_this)
        QDBusMessage __qt_return_value = __qt_this->QDBusPendingCall::reply();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::swap(QDBusPendingCall&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_swap_1native_1ref_1QDBusPendingCall__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    QTJAMBI_TRY {
        QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::swap(QDBusPendingCall&)", __qt_this)
        QDBusPendingCall& __qt_other0 = QtJambiAPI::interfaceReferenceFromNativeId<QDBusPendingCall>(__jni_env, other0);
        __qt_this->QDBusPendingCall::swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusPendingCall::waitForFinished()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_waitForFinished_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::waitForFinished()", __qt_this)
        __qt_this->QDBusPendingCall::waitForFinished();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusPendingCall::fromCompletedCall(QDBusMessage)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_fromCompletedCall_1native_1cref_1QDBusMessage__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID message0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusPendingCall::fromCompletedCall(QDBusMessage)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusMessage& __qt_message0 = QtJambiAPI::valueReferenceFromNativeId<QDBusMessage>(message0);
        QDBusPendingCall __qt_return_value = QDBusPendingCall::fromCompletedCall(__qt_message0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::fromError(QDBusError)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_fromError_1native_1cref_1QDBusError__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID error0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusPendingCall::fromError(QDBusError)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusError& __qt_error0 = QtJambiAPI::valueReferenceFromNativeId<QDBusError>(error0);
        QDBusPendingCall __qt_return_value = QDBusPendingCall::fromError(__qt_error0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeCustomStructors)
void* custom_constructor_QDBusPendingCall(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QDBusPendingCall* copy = static_cast<const QDBusPendingCall*>(__in_var);
    Q_UNUSED(copy)
    if(copy)
        return new(placement) QDBusPendingCall(*copy);
    else
        return new(placement) QDBusPendingCall(QDBusPendingCall::fromCompletedCall(QDBusMessage()));
}
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_clone_1native)
(JNIEnv *__jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDBusPendingCall(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceValueTypeInfo<QDBusPendingCall>("QDBusPendingCall", "io/qt/dbus/QDBusPendingCall");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDBusPendingCall, {
        ConstructorInfo(&__qt_construct_QDBusPendingCall_cref_QDBusPendingCall, "Lio/qt/dbus/QDBusPendingCall;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDBusPendingCall);
    registerMetaType<QDBusPendingCall>("QDBusPendingCall", &custom_constructor_QDBusPendingCall);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-dbus-debuginfo-macos-6.7.1.jar: sources/QtJambiDBus/QDBusPendingCall_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtDBus/qdbuspendingcall.h>
#include <QtCore/QVariant>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDBusPendingCall(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDBusPendingCall")
    QDBusPendingCall *_ptr = reinterpret_cast<QDBusPendingCall *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDBusPendingCall(QDBusPendingCall)
void __qt_construct_QDBusPendingCall_cref_QDBusPendingCall(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusPendingCall(QDBusPendingCall)")
    jobject other0 = __java_arguments[0].l;
    const QDBusPendingCall& __qt_other0 = qtjambi_cast<const QDBusPendingCall&>(__jni_env, other0);
    QDBusPendingCall *__qt_this = new(__qtjambi_ptr) QDBusPendingCall(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDBusPendingCall::QDBusPendingCall(QDBusPendingCall)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_initialize_1native__Lio_qt_dbus_QDBusPendingCall_2Lio_qt_dbus_QDBusPendingCall_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusPendingCall::QDBusPendingCall(QDBusPendingCall)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusPendingCall_cref_QDBusPendingCall, sizeof(QDBusPendingCall), typeid(QDBusPendingCall), 0, false, &deleter_QDBusPendingCall, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDBusPendingCall
void __qt_destruct_QDBusPendingCall(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDBusPendingCall")
    reinterpret_cast<QDBusPendingCall*>(ptr)->~QDBusPendingCall();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDBusPendingCall::error()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_error_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::error()const", __this_nativeId)
        QDBusError __qt_return_value = __qt_this->QDBusPendingCall::error();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::isError()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_isError_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::isError()const", __this_nativeId)
        __java_return_value = __qt_this->QDBusPendingCall::isError();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::isFinished()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_isFinished_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::isFinished()const", __this_nativeId)
        __java_return_value = __qt_this->QDBusPendingCall::isFinished();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::isValid()const", __this_nativeId)
        __java_return_value = __qt_this->QDBusPendingCall::isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::operator=(QDBusPendingCall)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_assign_1native_1cref_1QDBusPendingCall__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    QTJAMBI_TRY {
        QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::operator=(QDBusPendingCall)", __this_nativeId)
        const QDBusPendingCall& __qt_other0 = QtJambiAPI::interfaceReferenceFromNativeId<QDBusPendingCall>(__jni_env, other0);
        __qt_this->QDBusPendingCall::operator=(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusPendingCall::reply()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_reply_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::reply()const", __this_nativeId)
        QDBusMessage __qt_return_value = __qt_this->QDBusPendingCall::reply();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::swap(QDBusPendingCall&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_swap_1native_1ref_1QDBusPendingCall__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    QTJAMBI_TRY {
        QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::swap(QDBusPendingCall&)", __this_nativeId)
        QDBusPendingCall& __qt_other0 = QtJambiAPI::interfaceReferenceFromNativeId<QDBusPendingCall>(__jni_env, other0);
        __qt_this->QDBusPendingCall::swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusPendingCall::waitForFinished()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_waitForFinished_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusPendingCall::waitForFinished()", __this_nativeId)
        __qt_this->QDBusPendingCall::waitForFinished();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusPendingCall::fromCompletedCall(QDBusMessage)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_fromCompletedCall_1native_1cref_1QDBusMessage__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID message0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusPendingCall::fromCompletedCall(QDBusMessage)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusMessage& __qt_message0 = QtJambiAPI::valueReferenceFromNativeId<QDBusMessage>(message0);
        QDBusPendingCall __qt_return_value = QDBusPendingCall::fromCompletedCall(__qt_message0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusPendingCall::fromError(QDBusError)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_fromError_1native_1cref_1QDBusError__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID error0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusPendingCall::fromError(QDBusError)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusError& __qt_error0 = QtJambiAPI::valueReferenceFromNativeId<QDBusError>(error0);
        QDBusPendingCall __qt_return_value = QDBusPendingCall::fromError(__qt_error0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeCustomStructors)
void custom_default_constructor_QDBusPendingCall(const QtPrivate::QMetaTypeInterface *metaTypeInterface, void* placement)
{
    Q_UNUSED(metaTypeInterface)
    Q_UNUSED(placement)
    new(placement) QDBusPendingCall(QDBusPendingCall::fromCompletedCall(QDBusMessage()));
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusPendingCall_00024Impl_clone_1native)
(JNIEnv *__jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDBusPendingCall *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusPendingCall>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDBusPendingCall(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceValueTypeInfo<QDBusPendingCall>("QDBusPendingCall", "io/qt/dbus/QDBusPendingCall");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDBusPendingCall, {
        ConstructorInfo(&__qt_construct_QDBusPendingCall_cref_QDBusPendingCall, "Lio/qt/dbus/QDBusPendingCall;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDBusPendingCall);
    registerMetaType<QDBusPendingCall>("QDBusPendingCall", &custom_default_constructor_QDBusPendingCall, QtJambiPrivate::QMetaTypeInterfaceFunctions<QDBusPendingCall>::copyCtr, QtJambiPrivate::QMetaTypeInterfaceFunctions<QDBusPendingCall>::moveCtr);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
